task1_mareev_meledin
--------

This package is here to demonstrate the skill of creating packages.

To use, simply do: ::

    import import solve
    print(solve.nash_equilibrium([[1, 2], [3, 4]]))


Посмотрим на исходный код:
::

    Пример исходного кода

